# Rainbond Python

Rainbond python cloud native development base library.

## Reference

- [Restful API](https://www.runoob.com/w3cnote/restful-architecture.html) : Representational State Transfer
- [12 Factor](https://12factor.net/zh_cn/) : The twelve-factor app is a methodology for building software-as-a-service apps
- [RainBond](https://www.rainbond.com/docs/) : Cloud native and easy-to-use application management platform
